==> externalVector_1.0.3.tar.gz: externalVector/man/indirectExternalVector-class.Rd <==
\name{indirectExternalVector-class}
\docType{class}
\alias{indirectExternalVector-class}
\alias{Arith,ANY,indirectExternalVector-method}
\alias{Arith,indirectExternalVector,ANY-method}
\alias{Arith,indirectExternalVector,indirectExternalVector-method}
\alias{Compare,ANY,indirectExternalVector-method}
\alias{Compare,indirectExternalVector,ANY-method}
\alias{Compare,indirectExternalVector,indirectExternalVector-method}
\alias{Complex,indirectExternalVector-method}
\alias{Math,indirectExternalVector-method}
\alias{Ops,ANY,indirectExternalVector-method}
\alias{Ops,indirectExternalVector,ANY-method}
\alias{Ops,indirectExternalVector,indirectExternalVector-method}
\alias{Summary,indirectExternalVector,ANY-method}
\alias{[,indirectExternalVector,missing,missing,ANY-method}
\alias{[,indirectExternalVector,ANY,missing,ANY-method}
\alias{[<-,indirectExternalVector,missing,missing-method}
\alias{[<-,indirectExternalVector,ANY,missing-method}
\alias{all.na,indirectExternalVector-method}
\alias{any.na,indirectExternalVector-method}
\alias{as.Rvector,indirectExternalVector-method}
\alias{as.matrix,indirectExternalVector-method}
\alias{as.vector,indirectExternalVector,missing-method}
\alias{as.vector,indirectExternalVector,ANY-method}
\alias{coerce,externalVector,indirectExternalVector-method}
\alias{coerce,vector,indirectExternalVector-method}
\alias{coerce,indirectExternalVector,vector-method}
\alias{coerce,indirectExternalVector,matrix-method}
\alias{dim,indirectExternalVector-method}
\alias{dim<-,indirectExternalVector,ANY-method}
\alias{dimnames,indirectExternalVector-method}
\alias{dimnames<-,indirectExternalVector-method}
\alias{force,indirectExternalVector-method}
\alias{getExternalStorage,indirectExternalVector-method}
\alias{is.finite,indirectExternalVector-method}
\alias{is.infinite,indirectExternalVector-method}
\alias{is.na,indirectExternalVector-method}
\alias{is.nan,indirectExternalVector-method}
\alias{length,indirectExternalVector-method}
\alias{length<-,indirectExternalVector-method}
\alias{log,ANY,indirectExternalVector-method}
\alias{log,indirectExternalVector,ANY-method}
\alias{log,indirectExternalVector,indirectExternalVector-method}
\alias{log,indirectExternalVector,missing-method}
\alias{names,indirectExternalVector-method}
\alias{names<-,indirectExternalVector,NULL-method}
\alias{setNames,indirectExternalVector-method}
\alias{all,indirectExternalVector-method}
\alias{any,indirectExternalVector-method}
\alias{min,indirectExternalVector-method}
\alias{max,indirectExternalVector-method}
\alias{range,indirectExternalVector-method}
\alias{sum,indirectExternalVector-method}
\alias{prod,indirectExternalVector-method}

\title{Class "indirectExternalVector", class for indirect vector subset of an
  externalVector object. }
\description{ Objects from this class store an object of class
  \code{"externalVector"}  and a vector subscript for that object and
  behaves as if this is an object created by applying that subscript. }
\section{Objects from the Class}{
Objects can be created by calls of the form
\code{as("indirectExternalVector", vec)} where \code{vec} is an object
of class \code{"externalVector"}.
}
\section{Slots}{
  \describe{
    \item{\code{actual}:}{Object of class \code{"externalVector"}, the
      actual object of which this is a subset }
    \item{\code{index}:}{Object of class \code{"vectorIndex"}, the
      vector subscript to get the subset. }
  }
}
\section{Extends}{
Class \code{"externalVector"}, directly.
}
\section{Methods}{
  \describe{
    \item{e1 op e2}{ For any arithmetic or comparison operation \code{op}
      this returns the result of the operation. Either (or both) of
      \code{e1} and \code{e2} are of class
      \code{"indirectExternalVector"}. }
    \item{Complex(z)}{ Return the result of an operation in the
      \code{Complex} group generic. }
    \item{Math(x)}{ Return the result of an operation in the
      \code{Math} group generic. }
    \item{log(x)}{ Return natural logarithm of \code{x}. }
    \item{log(x, base)}{ Return logarithm of \code{x} with base
      \code{base}. }
    \item{x[i, j, \dots, drop=FALSE]}{ Extract a subset of \code{x}
      according to the given subscripts. }
    \item{x[i, j, \dots] <- value}{ Subassign of \code{x} by \code{value}
      according to the given subscripts. This assigns to the correct
      elements of \code{x@actual}. }
    \item{as.Rvector(x)}{ Coerce \code{x} to a basic R vector with same
      names, dimension and dimnames (if any of these are present in
      \code{x}). }
    \item{as.vector(x, mode)}{ Return an R basic vector with mode
      \code{mode}. }
    \item{as.matrix}{ Return a matrix of appropriate mode }.
    \item{length(x)}{ Return the length of \code{x}. }
    \item{length(x) <- value}{ Set the length of \code{x} to \code{value}. }
    \item{dim(x)}{ Return the dimension of \code{x}. }
    \item{dim(x) <- value}{ Set the dimension of \code{x} to \code{value}. }
    \item{dimnames(x)}{ Return the dimnames of \code{x}. }
    \item{dimnames(x) <- value}{ Set the dimnames of \code{x} to \code{value}. }
    \item{getExternalStorage(x)}{ Return the \code{storage} slot of
      associated with \code{x@actual}. }
    \item{is.finite(x)}{ Return a vector of logicals with same
      length as \code{x} indicating if an element of \code{x} is finite. }
    \item{is.infinite(x)}{ Return a vector of logicals with same
      length as \code{x} indicating if an element of \code{x} is infinite. }
    \item{is.na(x)}{ Return a vector of logicals with same
      length as \code{x} indicating if an element of \code{x} is \code{NA}. }
    \item{is.nan(x)}{ Return a vector of logicals with same
      length as \code{x} indicating if an element of \code{x} is \code{NaN}. }
    \item{setNames(x, value)}{ Set the names of \code{x} to \code{value}
      without any error checking or coercion. Return the modified
      \code{x}. }
    \item{force}{ return the result of \code{force(x@actual)[x@index]}. }
    \item{all(x, \dots, na.rm)}{ Are all the values \code{TRUE}? }
    \item{any(x, \dots, na.rm)}{ Are any of the values \code{TRUE}? }
    \item{min(x, \dots, na.rm)}{ Minima of the values. }
    \item{max(x, \dots, na.rm)}{ Maxima of the values. }
    \item{range(x, \dots, na.rm)}{ Range of the values. }
    \item{prod(x, \dots, na.rm)}{ Product of the values. }
    \item{sum(x, \dots, na.rm)}{ Sum of the values. }
  }
}
\seealso{
  \code{\link{indirectExternalMatrix-class}} for the matrix class
  corresponding to this.
}
\keyword{classes}

==> externalVector_1.4.0.tar.gz: externalVector/man/indirectExternalVector-class.Rd <==
\name{indirectExternalVector-class}
\docType{class}
\alias{indirectExternalVector-class}
\alias{Arith,ANY,indirectExternalVector-method}
\alias{Arith,indirectExternalVector,ANY-method}
\alias{Arith,indirectExternalVector,indirectExternalVector-method}
\alias{Compare,ANY,indirectExternalVector-method}
\alias{Compare,indirectExternalVector,ANY-method}
\alias{Compare,indirectExternalVector,indirectExternalVector-method}
\alias{Complex,indirectExternalVector-method}
\alias{Math,indirectExternalVector-method}
\alias{Ops,ANY,indirectExternalVector-method}
\alias{Ops,indirectExternalVector,ANY-method}
\alias{Ops,indirectExternalVector,indirectExternalVector-method}
\alias{Summary,indirectExternalVector,ANY-method}
\alias{[,indirectExternalVector,missing,missing,ANY-method}
\alias{[,indirectExternalVector,ANY,missing,ANY-method}
\alias{[<-,indirectExternalVector,missing,missing-method}
\alias{[<-,indirectExternalVector,ANY,missing-method}
\alias{allNA,indirectExternalVector-method}
\alias{anyNA,indirectExternalVector-method}
\alias{as.Rvector,indirectExternalVector-method}
\alias{as.matrix,indirectExternalVector-method}
\alias{as.vector,indirectExternalVector,missing-method}
\alias{as.vector,indirectExternalVector,ANY-method}
\alias{coerce,externalVector,indirectExternalVector-method}
\alias{coerce,vector,indirectExternalVector-method}
\alias{coerce,indirectExternalVector,vector-method}
\alias{coerce,indirectExternalVector,matrix-method}
\alias{dim,indirectExternalVector-method}
\alias{dim<-,indirectExternalVector,ANY-method}
\alias{dimnames,indirectExternalVector-method}
\alias{dimnames<-,indirectExternalVector-method}
\alias{force,indirectExternalVector-method}
\alias{getExternalStorage,indirectExternalVector-method}
\alias{is.finite,indirectExternalVector-method}
\alias{is.infinite,indirectExternalVector-method}
\alias{is.na,indirectExternalVector-method}
\alias{is.nan,indirectExternalVector-method}
\alias{length,indirectExternalVector-method}
\alias{length<-,indirectExternalVector-method}
\alias{log,ANY,indirectExternalVector-method}
\alias{log,indirectExternalVector,ANY-method}
\alias{log,indirectExternalVector,indirectExternalVector-method}
\alias{log,indirectExternalVector,missing-method}
\alias{names,indirectExternalVector-method}
\alias{names<-,indirectExternalVector,NULL-method}
\alias{setNames,indirectExternalVector-method}
\alias{all,indirectExternalVector-method}
\alias{any,indirectExternalVector-method}
\alias{min,indirectExternalVector-method}
\alias{max,indirectExternalVector-method}
\alias{range,indirectExternalVector-method}
\alias{sum,indirectExternalVector-method}
\alias{prod,indirectExternalVector-method}

\title{Class "indirectExternalVector", class for indirect vector subset of an
  externalVector object. }
\description{ Objects from this class store an object of class
  \code{"externalVector"}  and a vector subscript for that object and
  behaves as if this is an object created by applying that subscript. }
\section{Objects from the Class}{
Objects can be created by calls of the form
\code{as("indirectExternalVector", vec)} where \code{vec} is an object
of class \code{"externalVector"}.
}
\section{Slots}{
  \describe{
    \item{\code{actual}:}{Object of class \code{"externalVector"}, the
      actual object of which this is a subset }
    \item{\code{index}:}{Object of class \code{"vectorIndex"}, the
      vector subscript to get the subset. }
  }
}
\section{Extends}{
Class \code{"externalVector"}, directly.
}
\section{Methods}{
  \describe{
    \item{e1 op e2}{ For any arithmetic or comparison operation \code{op}
      this returns the result of the operation. Either (or both) of
      \code{e1} and \code{e2} are of class
      \code{"indirectExternalVector"}. }
    \item{Complex(z)}{ Return the result of an operation in the
      \code{Complex} group generic. }
    \item{Math(x)}{ Return the result of an operation in the
      \code{Math} group generic. }
    \item{log(x)}{ Return natural logarithm of \code{x}. }
    \item{log(x, base)}{ Return logarithm of \code{x} with base
      \code{base}. }
    \item{x[i, j, \dots, drop=FALSE]}{ Extract a subset of \code{x}
      according to the given subscripts. }
    \item{x[i, j, \dots] <- value}{ Subassign of \code{x} by \code{value}
      according to the given subscripts. This assigns to the correct
      elements of \code{x@actual}. }
    \item{as.Rvector(x)}{ Coerce \code{x} to a basic R vector with same
      names, dimension and dimnames (if any of these are present in
      \code{x}). }
    \item{as.vector(x, mode)}{ Return an R basic vector with mode
      \code{mode}. }
    \item{as.matrix}{ Return a matrix of appropriate mode }.
    \item{length(x)}{ Return the length of \code{x}. }
    \item{length(x) <- value}{ Set the length of \code{x} to \code{value}. }
    \item{dim(x)}{ Return the dimension of \code{x}. }
    \item{dim(x) <- value}{ Set the dimension of \code{x} to \code{value}. }
    \item{dimnames(x)}{ Return the dimnames of \code{x}. }
    \item{dimnames(x) <- value}{ Set the dimnames of \code{x} to \code{value}. }
    \item{getExternalStorage(x)}{ Return the \code{storage} slot of
      associated with \code{x@actual}. }
    \item{is.finite(x)}{ Return a vector of logicals with same
      length as \code{x} indicating if an element of \code{x} is finite. }
    \item{is.infinite(x)}{ Return a vector of logicals with same
      length as \code{x} indicating if an element of \code{x} is infinite. }
    \item{is.na(x)}{ Return a vector of logicals with same
      length as \code{x} indicating if an element of \code{x} is \code{NA}. }
    \item{is.nan(x)}{ Return a vector of logicals with same
      length as \code{x} indicating if an element of \code{x} is \code{NaN}. }
    \item{setNames(x, value)}{ Set the names of \code{x} to \code{value}
      without any error checking or coercion. Return the modified
      \code{x}. }
    \item{force}{ return the result of \code{force(x@actual)[x@index]}. }
    \item{all(x, \dots, na.rm)}{ Are all the values \code{TRUE}? }
    \item{any(x, \dots, na.rm)}{ Are any of the values \code{TRUE}? }
    \item{min(x, \dots, na.rm)}{ Minima of the values. }
    \item{max(x, \dots, na.rm)}{ Maxima of the values. }
    \item{range(x, \dots, na.rm)}{ Range of the values. }
    \item{prod(x, \dots, na.rm)}{ Product of the values. }
    \item{sum(x, \dots, na.rm)}{ Sum of the values. }
  }
}
\seealso{
  \code{\link{indirectExternalMatrix-class}} for the matrix class
  corresponding to this.
}
\keyword{classes}
